@@ -53,6 +53,8 @@ hammcrit = function(x){
 
 
 
+
+
 #indep.class.crit = function(M){
 #	ttx = rowSums(M)
 #	tty = colSums(M)
@@ -68,6 +70,7 @@ hammcrit = function(x){
 iccrit = function(x){
 	crt <- 1
 	n <- sum(x)
+	if(n == 0) return(0)
 	if(is.null(dim(x))){
 	  ss <- x/n
 	   piv <- outer(ss,ss)
@@ -107,15 +110,18 @@ ihcrit = function(x){
 	ttx = colSums(x)
 	n <- nrow(x)
 	m <- ncol(x)
+	if((N<-sum(x)) == 0) return(0)
 		yo <- c(seq(1,n,2),rev(seq(2,n,2)))
 		xo <- c(seq(1,m,2),rev(seq(2,m,2)))
-	
+	x <- (tty %*% t(ttx))/N
 	x <- (x[order(tty), order(ttx)])[yo,xo]
 	return(hammcrit(x))
 }	
 
 WBCI = function(x){
-	hammcrit(x)/ihcrit(x)
+	ih <- ihcrit(x)
+	if(abs(ih) < 1e-12){return(1)}
+	hammcrit(x)/ih
 }
 
 
@@ -133,6 +139,24 @@ sccrit = function(x, concordant = FALSE){
 }
 
 
+itab = function(x){
+    
+    dims <- dim(x)
+    nd <- length(dims)
+    N <- sum(x)
+    
+    p1 <- apply(x,1,sum)
+    p2 <- apply(x,2,sum)
+    IM <- p1 %o% p2 /N
+    if(nd > 2){
+        for(j in 3:nd){
+            p3 <- apply(x,j,sum)
+            IM <- IM %o% p3/N
+        }
+    }
+    dim(IM) <- dim(x)
+    return(IM)
+}
 
 
 
@@ -251,7 +275,10 @@ allpairs = function(x){
 
 BCI <- function(x){
 	nd <- length(dim(x))
-	ret <- (allpairs(x)-classcrit(x))/iccrit(x)/(2^(nd-1)-1)
+	ic <- iccrit(x)
+	if(abs(ic) < 1e-12){return(1)}
+	
+	ret <- (allpairs(x)-classcrit(x))/ic/(2^(nd-1)-1)
 	return(ret)
 }
 
@@ -263,3 +290,117 @@ BCC = function(x){
 	return(ret)
 }
 
+
+
+
+cohen <- function(x){
+	stopifnot(length(dim(x))==2)
+	N <- sum(x)
+	sq<-lapply(dim(x),function(z){
+		(0:(z-1))/(z-1)
+	})
+	D1<-sapply(sq[[1]],function(z){
+		abs(z-sq[[2]])
+	})
+	D2<-sapply(sq[[2]],function(z){
+		abs(z-sq[[1]])
+	})
+	
+	D<-1-(t(D1)+D2)/2
+	
+	dt <- sum(D*x)/N 
+	ch <- sum(itab(x)*D)/N
+	kappa <- (dt-ch)/(1-ch)
+	return(kappa)
+	
+}
+
+
+ME <- function(x){
+	nd <- length(dim(x))
+	Z <- lapply(dim(x),function(z){
+		ret <- rbind(cbind(0,diag(1,z-1,z-1)),0)
+		diag(ret) <- 1
+		ret
+	})
+	ret <- 0
+	for(i in 1:nd){
+		M <- apply(x,i,as.vector)
+		for(j in 1:(ncol(M)-1)){
+			ret <- ret + sum(M[,j]*M[,j+1])
+		}
+		
+	}
+	return(ret)
+	
+}
+
+
+optME<-
+function (x, dims = NULL,nstart = 1, solver = "nearest_insertion", return.table = TRUE, adjust.dist = FALSE) 
+{
+    nd <- length(dim(x))
+    
+    ind <- c(1:nd)
+    
+   if(is.null(dims)){
+   	dims <- ind
+   }
+  
+    D <- lapply(ind, function(d) {
+    	
+    		if(! d %in% dims ){
+    			return(1:dim(x)[d])
+    		}
+    	
+        M <- apply(x, d, as.vector)
+        d <- t(M) %*% M
+        d <- max(d) - d
+        
+        if(adjust.dist){
+    		edist <- dist(t(M))
+    		d <- d + as.matrix(edist)/10
+    	}
+    	
+        ts <- TSP(d)
+        ts <- insert_dummy(ts, n = 1, label = "cut")
+        return(ts)
+    })
+  
+
+    require(TSP)
+    ords <- lapply(D, function(d) {
+    	if(!inherits(d, "TSP")){
+    		return(d)
+    	}
+    	st <- system.time({
+        ns <- min(nstart, attr(d, "Size"))
+        sp <- sample(1:attr(d, "Size"), ns, replace = FALSE)
+        tl1 <- Inf
+        for (i in sp) {
+            sts <- solve_TSP(d, method = solver, control = list(start = as.integer(i)))
+            tl0 <- attr(sts, "tour_length")
+            if (tl0 < tl1) {
+                ord <- cut_tour(sts, "cut")
+                tl1 <- tl0
+            }
+        }
+        
+        })
+        return(ord)
+    })
+    if(return.table){
+    	data <- as.data.frame(as.table(x))
+    	for (i in 1:nd) {
+       	 data[, i] <- factor(data[, i], levels = levels(as.factor(data[, 
+           	 i]))[ords[[i]]])
+    	}
+    	tt <- xtabs(Freq ~ ., data = data)
+    	attr(tt,"orders") <- ords
+    	return(tt)
+     }
+    return(ords)
+}
+
+
+
